@@ -1,9 +1,9 @@
 # Simple test function to test out SLICOT interface
 # RMM, 28 May 09
 
+import numpy as np              # Numerical library
 from scipy import *             # Load the scipy functions
-from control import *           # Load the controls systems library
-from slicot import ab01md       # Load test function interface
+from control.matlab import *    # Load the controls systems library
 
 # Parameters defining the system
 m = 250.0			# system mass
@@ -16,5 +16,11 @@ B = matrix([[0], [1/m], [1]])
 C = matrix([[1., 0, 1.]])
 sys = ss(A, B, C, 0);
 
-Ac, Bc, ncont, info = ab01md('I', A, B)
+# Eigenvalue placement
+#from slycot import sb01bd
+K = place(A, B, [-3, -2, -1])
+print "Pole place: K = ", K
+print "Pole place: eigs = ", np.linalg.eig(A - B * K)[0]
 
+# from slycot import ab01md
+# Ac, Bc, ncont, info = ab01md('I', A, B)
